<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!-- ==========================================================================

Licensed Materials-Property of IBM

(C)Copyright IBM Corp 2004

All rights reserved

US Government Users Restricted Rights
Use, duplication, or disclosure restricted
by GSA ADP Schedule Contract with IBM Corp


code/catalog/util/src/com/ibm/events/catalog/util/extensionToCategoryBindings.xsl, cei_catalog, cei_5.1.0, 200403152330
@Version 1.2 3/15/04

===============================================================================

This stylesheet is used to output a list of Common Base Event extension name -
event source category bindings in human-readable format.

This stylesheet operates on an XML document having the following form.
 
<?xml version="1.0" encoding="UTF-8"?>
<bindings>
  <category category="fruit">
    <name name="apple"/>
    <name name="banana"/>
  </category>
  <category category="green">
    <name name="apple"/>
    <name name="leaf"/>
  </category>
</bindings>

Predefined strings such as the title and heading are passed in as parameters.
This allows them to be localized.
 
=========================================================================== -->

<xsl:output method="text" omit-xml-declaration="yes"/>


<!-- ==========================================================================
Parameters for each of the predefined strings used throughout the stylesheet.
The strings are localized by the calling program.
These parameters must correspond one-one with resources in 
CeiCatalogResources.properties.
=========================================================================== -->

<xsl:param name="title_text"/>
<xsl:param name="heading_text"/>
<xsl:param name="heading_separator_text"/>


<!-- ==========================================================================
A template that matches the top-level bindings element.
It outputs a header and then applies the template for any
category elements contained within it.
=========================================================================== -->

<xsl:template match="bindings">
<xsl:value-of select="$title_text"/><xsl:text>

</xsl:text><xsl:value-of select="$heading_text"/><xsl:text>
</xsl:text><xsl:value-of select="$heading_separator_text"/><xsl:text>
</xsl:text>
<xsl:apply-templates select="category"/>
</xsl:template>


<!-- ==========================================================================
A template that matches a category element.
=========================================================================== -->

<xsl:template match="category">
<xsl:value-of select="@category" />
<xsl:apply-templates select="name"/>
<xsl:text>
</xsl:text>
</xsl:template>


<!-- ==========================================================================
A template that matches a name element.
=========================================================================== -->

<xsl:template match="name">
    - <xsl:value-of select="@name" />
</xsl:template>

</xsl:stylesheet>
